@@ -68,7 +68,7 @@ def extract_read_name(bam,out_dir,virRef,window):
             if '>' in each:
                 virus_chrm_list.append(each.split()[0].replace('>',''))
     for virus_chrm in virus_chrm_list:
-        invalidCharacter = set(string.punctuation)
+        invalidCharacter = str(string.punctuation)
         virus_chrm_file_name = virus_chrm.replace(invalidCharacter,"_")
         fusionRes = f'{out_dir}/call_fusion/{virus_chrm_file_name}.all.filtered.clustered.result'
         check_file(fusionRes)
