@@ -26,7 +26,7 @@ def genomeFusion(window,out_dir,virRef):
         #filter and cluster fusion points
         ##sort result
         #if there are invalid characters in the chromosome name:
-        invalidCharacter = set(string.punctuation)
+        invalidCharacter = str(string.punctuation)
         virus_chrm_file_name = virus_chrm.replace(invalidCharacter,"_")
         os.system(f'(head -n 1 {res} && tail -n +2 {res} | sort -k3,3rn) > {out_dir}/{virus_chrm_file_name}.genome_fusion.sort.txt')
 
