@@ -27,5 +27,5 @@ def virus_fusion(humRef,virRef,out_dir,n):
     siteConfidence = siteConf(out_dir)
     # print(siteConfidence.keys())
     # print(selectedAllContig.keys())
-    filteredSelectedContig = filter_res(selectedAllContig,siteConfidence,out_dir)
+    filteredSelectedContig = filter_res(selectedAllContig,siteConfidence)
     write_to_file(filteredSelectedContig,siteConfidence,out_dir,n)
